@@ -88,12 +88,12 @@ will be the same as:
 
 but will even work for perl-5.6 for chars in the 128 .. 255 range.
 
-Note: Javascript has a function called escape() that produce the
+Note: Javascript has a function called escape() that produces the
 sequence "%uXXXX" for chars in the 256 .. 65535 range.  This function
 has really nothing to do with URI escaping but some folks got confused
 since it "does the right thing" in the 0 .. 255 range.  Because of
 this you sometimes see "URIs" with these kind of escapes.  The
-JavaScript encodeURI() function is similar to uri_escape_utf8().
+JavaScript encodeURIComponent() function is similar to uri_escape_utf8().
 
 =item uri_unescape($string,...)
 
